==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/iotoperationsmq/kotlin/outputs/GetKafkaConnectorResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.iotoperationsmq.kotlin.outputs

import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map

/**
 * MQ kafkaConnector resource
 * @property clientIdPrefix The client id prefix of the dynamically generated client ids.
 * @property extendedLocation Extended Location
 * @property id Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
 * @property image The details of KafkaConnector Docker Image.
 * @property instances The number of KafkaConnector pods to spin up.
 * @property kafkaConnection The details for connecting with Remote Kafka Broker.
 * @property localBrokerConnection The details for connecting with Local Broker.
 * @property location The geo-location where the resource lives
 * @property logLevel The log level of the Bridge Connector instances.
 * @property name The name of the resource
 * @property nodeTolerations The Node Tolerations for the Bridge Connector pods.
 * @property provisioningState The status of the last operation.
 * @property systemData Azure Resource Manager metadata containing createdBy and modifiedBy information.
 * @property tags Resource tags.
 * @property type The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
 */
public data class GetKafkaConnectorResult(
    public val clientIdPrefix: String? = null,
    public val extendedLocation: ExtendedLocationPropertyResponse,
    public val id: String,
    public val image: ContainerImageResponse? = null,
    public val instances: Int? = null,
    public val kafkaConnection: KafkaRemoteBrokerConnectionSpecResponse,
    public val localBrokerConnection: LocalBrokerConnectionSpecResponse? = null,
    public val location: String,
    public val logLevel: String? = null,
    public val name: String,
    public val nodeTolerations: NodeTolerationsResponse? = null,
    public val provisioningState: String,
    public val systemData: SystemDataResponse,
    public val tags: Map<String, String>? = null,
    public val type: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.iotoperationsmq.outputs.GetKafkaConnectorResult):
            GetKafkaConnectorResult = GetKafkaConnectorResult(
            clientIdPrefix = javaType.clientIdPrefix().map({ args0 -> args0 }).orElse(null),
            extendedLocation = javaType.extendedLocation().let({ args0 ->
                com.pulumi.azurenative.iotoperationsmq.kotlin.outputs.ExtendedLocationPropertyResponse.Companion.toKotlin(args0)
            }),
            id = javaType.id(),
            image = javaType.image().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.iotoperationsmq.kotlin.outputs.ContainerImageResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            instances = javaType.instances().map({ args0 -> args0 }).orElse(null),
            kafkaConnection = javaType.kafkaConnection().let({ args0 ->
                com.pulumi.azurenative.iotoperationsmq.kotlin.outputs.KafkaRemoteBrokerConnectionSpecResponse.Companion.toKotlin(args0)
            }),
            localBrokerConnection = javaType.localBrokerConnection().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.iotoperationsmq.kotlin.outputs.LocalBrokerConnectionSpecResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            location = javaType.location(),
            logLevel = javaType.logLevel().map({ args0 -> args0 }).orElse(null),
            name = javaType.name(),
            nodeTolerations = javaType.nodeTolerations().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.iotoperationsmq.kotlin.outputs.NodeTolerationsResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            provisioningState = javaType.provisioningState(),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.iotoperationsmq.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            tags = javaType.tags().map({ args0 -> args0.key.to(args0.value) }).toMap(),
            type = javaType.type(),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/iotoperationsmq/kotlin/outputs/GetKafkaConnectorResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.iotoperationsmq.kotlin.outputs

import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map

/**
 * MQ kafkaConnector resource
 * @property clientIdPrefix The client id prefix of the dynamically generated client ids.
 * @property extendedLocation Extended Location
 * @property id Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
 * @property image The details of KafkaConnector Docker Image.
 * @property instances The number of KafkaConnector pods to spin up.
 * @property kafkaConnection The details for connecting with Remote Kafka Broker.
 * @property localBrokerConnection The details for connecting with Local Broker.
 * @property location The geo-location where the resource lives
 * @property logLevel The log level of the Bridge Connector instances.
 * @property name The name of the resource
 * @property nodeTolerations The Node Tolerations for the Bridge Connector pods.
 * @property provisioningState The status of the last operation.
 * @property systemData Azure Resource Manager metadata containing createdBy and modifiedBy information.
 * @property tags Resource tags.
 * @property type The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
 */
public data class GetKafkaConnectorResult(
    public val clientIdPrefix: String? = null,
    public val extendedLocation: ExtendedLocationPropertyResponse,
    public val id: String,
    public val image: ContainerImageResponse? = null,
    public val instances: Int? = null,
    public val kafkaConnection: KafkaRemoteBrokerConnectionSpecResponse,
    public val localBrokerConnection: LocalBrokerConnectionSpecResponse? = null,
    public val location: String,
    public val logLevel: String? = null,
    public val name: String,
    public val nodeTolerations: NodeTolerationsResponse? = null,
    public val provisioningState: String,
    public val systemData: SystemDataResponse,
    public val tags: Map<String, String>? = null,
    public val type: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.iotoperationsmq.outputs.GetKafkaConnectorResult): GetKafkaConnectorResult = GetKafkaConnectorResult(
            clientIdPrefix = javaType.clientIdPrefix().map({ args0 -> args0 }).orElse(null),
            extendedLocation = javaType.extendedLocation().let({ args0 ->
                com.pulumi.azurenative.iotoperationsmq.kotlin.outputs.ExtendedLocationPropertyResponse.Companion.toKotlin(args0)
            }),
            id = javaType.id(),
            image = javaType.image().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.iotoperationsmq.kotlin.outputs.ContainerImageResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            instances = javaType.instances().map({ args0 -> args0 }).orElse(null),
            kafkaConnection = javaType.kafkaConnection().let({ args0 ->
                com.pulumi.azurenative.iotoperationsmq.kotlin.outputs.KafkaRemoteBrokerConnectionSpecResponse.Companion.toKotlin(args0)
            }),
            localBrokerConnection = javaType.localBrokerConnection().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.iotoperationsmq.kotlin.outputs.LocalBrokerConnectionSpecResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            location = javaType.location(),
            logLevel = javaType.logLevel().map({ args0 -> args0 }).orElse(null),
            name = javaType.name(),
            nodeTolerations = javaType.nodeTolerations().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.iotoperationsmq.kotlin.outputs.NodeTolerationsResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            provisioningState = javaType.provisioningState(),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.iotoperationsmq.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            tags = javaType.tags().map({ args0 -> args0.key.to(args0.value) }).toMap(),
            type = javaType.type(),
        )
    }
}
